==> batchtools_0.9.0.tar.gz: batchtools/tests/testthat/test_showLog.R <==
context("showLog/getLog")

test_that("showLog/getLog", {
  reg = makeRegistry(file.dir = NA, make.default = FALSE)
  batchMap(function(x) print("GREPME"), 1:2, reg = reg)
  expect_error(showLog(id = 1, reg = reg), "not available")
  expect_error(readLog(id = 1, reg = reg), "not available")
  submitAndWait(reg)

  lines = getLog(id = 1, reg = reg)
  expect_character(lines, min.len = 3L, any.missing = FALSE)
  expect_equal(sum(stri_detect_fixed(lines, "GREPME")), 1L)
  expect_true(any(stri_startswith_fixed(lines, "### [bt ")))
  expect_identical(sum(stri_endswith_fixed(lines, "[batchtools job.id=1]")), 2L)
  expect_false(any(stri_endswith_fixed(lines, "[batchtools job.id=2]")))

  lines = getLog(id = 2, reg = reg)
  expect_false(any(stri_endswith_fixed(lines, "[batchtools job.id=1]")))

  with_options(list(pager = function(files, header, title, delete.file) files), {
    x = showLog(id = 2, reg = reg)
    expect_equal(basename(x), "2.log")
    expect_equal(sum(stri_detect_fixed(readLines(x), "GREPME")), 1L)
  })

  expect_error(getLog(id = 1:2, reg = reg), "exactly")
  expect_error(getLog(id = 3, reg = reg), "exactly")
})

test_that("empty log files", {
  reg = makeRegistry(file.dir = NA, make.default = FALSE)
  batchMap(identity, 1, reg = reg)
  submitAndWait(reg)

  # overwrite log file
  log.file = file.path(reg$file.dir, "logs", sprintf("%s.log", reg$status[1, job.hash]))
  file.remove(log.file)
  file.create(log.file)

  x = readLog(list(1), reg = reg)
  expect_data_table(x, ncol = 2, nrow = 0, index = "job.id")

  expect_equal(getLog(1, reg = reg), character(0L))
})

==> batchtools_0.9.2.tar.gz: batchtools/tests/testthat/test_showLog.R <==
context("showLog/getLog")

test_that("showLog/getLog", {
  reg = makeRegistry(file.dir = NA, make.default = FALSE)
  batchMap(function(x) print("GREPME"), 1:2, reg = reg)
  expect_error(showLog(id = 1, reg = reg), "not available")
  expect_error(readLog(id = 1, reg = reg), "not available")
  submitAndWait(reg)

  lines = getLog(id = 1, reg = reg)
  expect_character(lines, min.len = 3L, any.missing = FALSE)
  expect_equal(sum(stri_detect_fixed(lines, "GREPME")), 1L)
  expect_true(any(stri_startswith_fixed(lines, "### [bt ")))
  expect_identical(sum(stri_endswith_fixed(lines, "[batchtools job.id=1]")), 2L)
  expect_false(any(stri_endswith_fixed(lines, "[batchtools job.id=2]")))

  lines = getLog(id = 2, reg = reg)
  expect_false(any(stri_endswith_fixed(lines, "[batchtools job.id=1]")))

  with_options(list(pager = function(files, header, title, delete.file) files), {
    x = showLog(id = 2, reg = reg)
    expect_equal(basename(x), "2.log")
    expect_equal(sum(stri_detect_fixed(readLines(x), "GREPME")), 1L)
  })

  expect_error(getLog(id = 1:2, reg = reg), "exactly")
  expect_error(getLog(id = 3, reg = reg), "exactly")
})

test_that("empty log files", {
  reg = makeRegistry(file.dir = NA, make.default = FALSE)
  batchMap(identity, 1, reg = reg)
  submitAndWait(reg)

  # overwrite log file
  log.file = getLogFiles(reg, reg$status[1])
  expect_true(file.remove(log.file))
  expect_true(file.create(log.file))

  x = readLog(list(1), reg = reg)
  expect_data_table(x, ncol = 2, nrow = 0, index = "job.id")

  expect_equal(getLog(1, reg = reg), character(0L))
})
